===================================================
``psyclone.psyir.transformations.chunk_loop_trans``
===================================================

.. automodule:: psyclone.psyir.transformations.chunk_loop_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.chunk_loop_trans
